@@ -21,7 +21,7 @@ Usage::
     get_attribute_values_paginator: GetAttributeValuesPaginator = client.get_paginator("get_attribute_values")
     get_products_paginator: GetProductsPaginator = client.get_paginator("get_products")
 """
-from mypy_boto3_pricing.client import PricingClient as Client, PricingClient
+from mypy_boto3_pricing.client import PricingClient, PricingClient as Client
 from mypy_boto3_pricing.paginator import (
     DescribeServicesPaginator,
     GetAttributeValuesPaginator,
